@@ -148,7 +148,7 @@ class CSIDriver(Resource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
