@@ -33,5 +33,5 @@ class OperatorGroup(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({"spec": {"targetNamespaces": self.target_namespaces}})
