@@ -48,14 +48,6 @@ LOGGER = get_logger(name=__name__)
 MAX_SUPPORTED_API_VERSION = "v2"
 
 
-class MissingRequiredArgumentError(Exception):
-    def __init__(self, argument: str) -> None:
-        self.argument = argument
-
-    def __repr__(self) -> str:
-        return f"Missing required argument/s. Either provide yaml_file or pass {self.argument}"
-
-
 def _find_supported_resource(dyn_client: DynamicClient, api_group: str, kind: str) -> Optional[ResourceField]:
     results = dyn_client.resources.search(group=api_group, kind=kind)
     sorted_results = sorted(results, key=lambda result: KubeAPIVersion(result.api_version), reverse=True)
@@ -141,6 +133,23 @@ def sub_resource_level(current_class: Any, owner_class: Any, parent_class: Any)
     return None
 
 
+# Exceptions classes
+class MissingRequiredArgumentError(Exception):
+    def __init__(self, argument: str) -> None:
+        self.argument = argument
+
+    def __repr__(self) -> str:
+        return f"Missing required argument/s. Either provide yaml_file, kind_dict or pass {self.argument}"
+
+
+class MissingResourceResError(Exception):
+    def __repr__(self) -> str:
+        return "Failed to generate resource self.res"
+
+
+# End Exceptions classes
+
+
 class KubeAPIVersion(Version):
     """
     Implement the Kubernetes API versioning scheme from
@@ -202,12 +211,6 @@ class ClassProperty:
         return self.func(owner)
 
 
-class ValueMismatch(Exception):
-    """
-    Raises when value doesn't match the class value
-    """
-
-
 class Resource:
     """
     Base class for API resources
@@ -253,6 +256,11 @@ class Resource:
         class Reason:
             ALL_REQUIREMENTS_MET: str = "AllRequirementsMet"
             INSTALL_SUCCEEDED: str = "InstallSucceeded"
+            NETWORK_ATTACHMENT_DEFINITION_READY: str = "NetworkAttachmentDefinitionReady"
+            SYNC_ERROR: str = "SyncError"
+
+        class Type:
+            NETWORK_READY: str = "NetworkReady"
 
     class Interface:
         class State:
@@ -295,7 +303,7 @@ class Resource:
         INTEGREATLY_ORG: str = "integreatly.org"
         K8S_CNI_CNCF_IO: str = "k8s.cni.cncf.io"
         K8S_MARIADB_COM: str = "k8s.mariadb.com"
-        K8S_OVN_ORG: str = "k8s.ovn.org/v1"
+        K8S_OVN_ORG: str = "k8s.ovn.org"
         K8S_V1_CNI_CNCF_IO: str = "k8s.v1.cni.cncf.io"
         KUBERNETES_IO: str = "kubernetes.io"
         KUBEVIRT_IO: str = "kubevirt.io"
@@ -382,10 +390,13 @@ class Resource:
         api_group: str = "",
         hash_log_data: bool = True,
         ensure_exists: bool = False,
+        kind_dict: Dict[Any, Any] | None = None,
     ):
         """
         Create an API resource
 
+        If `yaml_file` or `kind_dict` are passed, logic in `to_dict` is bypassed.
+
         Args:
             name (str): Resource name
             client (DynamicClient): Dynamic client for connecting to a remote cluster
@@ -406,13 +417,17 @@ class Resource:
             hash_log_data (bool): Hash resource content based on resource keys_to_hash property
                 (example: Secret resource)
             ensure_exists (bool): Whether to check if the resource exists before when initializing the resource, raise if not.
+            kind_dict (dict): dict which represents the resource object
         """
+        if yaml_file and kind_dict:
+            raise ValueError("yaml_file and resource_dict are mutually exclusive")
 
         self.name = name
         self.teardown = teardown
         self.timeout = timeout
         self.privileged_client = privileged_client
         self.yaml_file = yaml_file
+        self.kind_dict = kind_dict
         self.delete_timeout = delete_timeout
         self.dry_run = dry_run
         self.node_selector = node_selector
@@ -435,13 +450,12 @@ class Resource:
         if not self.api_group and not self.api_version:
             raise NotImplementedError("Subclasses of Resource require self.api_group or self.api_version to be defined")
 
-        if not (self.name or self.yaml_file):
+        if not (self.name or self.yaml_file or self.kind_dict):
             raise MissingRequiredArgumentError(argument="name")
 
         self.namespace: str = ""
-        self.resource_dict: Dict[str, Any] = {}  # Filled in case yaml_file is not None
         self.node_selector_spec = self._prepare_node_selector_spec()
-        self.res: Dict[Any, Any] = {}
+        self.res: Dict[Any, Any] = self.kind_dict or {}
         self.yaml_file_contents: str = ""
         self.initial_resource_version: str = ""
         self.logger = self._set_logger()
@@ -480,28 +494,39 @@ class Resource:
         Returns:
             dict: Resource dict.
         """
-        if self.yaml_file:
+        if self.kind_dict:
+            # If `kind_dict` is provided, no additional logic should be applied
+            self.name = self.kind_dict["metadata"]["name"]
+
+        elif self.yaml_file:
             if not self.yaml_file_contents:
                 if isinstance(self.yaml_file, StringIO):
                     self.yaml_file_contents = self.yaml_file.read()
+
                 else:
-                    with open(self.yaml_file, "r") as stream:
+                    with open(self.yaml_file) as stream:
                         self.yaml_file_contents = stream.read()
 
             self.res = yaml.safe_load(stream=self.yaml_file_contents)
             self.res.get("metadata", {}).pop("resourceVersion", None)
             self.name = self.res["metadata"]["name"]
+
         else:
             self.res = {
                 "apiVersion": self.api_version,
                 "kind": self.kind,
                 "metadata": {"name": self.name},
             }
+
             if self.label:
                 self.res.setdefault("metadata", {}).setdefault("labels", {}).update(self.label)
+
             if self.annotations:
                 self.res.setdefault("metadata", {}).setdefault("annotations", {}).update(self.annotations)
 
+        if not self.res:
+            raise MissingResourceResError()
+
     def to_dict(self) -> None:
         """
         Generate intended dict representation of the resource.
@@ -773,12 +798,8 @@ class Resource:
 
         Returns:
             bool: True if create succeeded, False otherwise.
-
-        Raises:
-            ValueMismatch: When body value doesn't match class value
         """
-        if not self.res:
-            self.to_dict()
+        self.to_dict()
 
         hashed_res = self.hash_resource_dict(resource_dict=self.res)
         self.logger.info(f"Create {self.kind} {self.name}")
@@ -1219,7 +1240,7 @@ class NamespacedResource(Resource):
             **kwargs,
         )
         self.namespace = namespace
-        if not (self.name and self.namespace) and not self.yaml_file:
+        if not (self.name and self.namespace) and not self.yaml_file and not self.kind_dict:
             raise MissingRequiredArgumentError(argument="'name' and 'namespace'")
 
         if ensure_exists:
@@ -1293,19 +1314,17 @@ class NamespacedResource(Resource):
         return self.retry_cluster_exceptions(func=_instance)
 
     def _base_body(self) -> None:
-        if not self.res:
-            super(NamespacedResource, self)._base_body()
-
-        if self.yaml_file:
+        if self.yaml_file or self.kind_dict:
             self.namespace = self.res["metadata"].get("namespace", self.namespace)
 
+        else:
+            self.res["metadata"]["namespace"] = self.namespace
+
         if not self.namespace:
             raise MissingRequiredArgumentError(argument="namespace")
 
-        if not self.yaml_file:
-            self.res["metadata"]["namespace"] = self.namespace
-
     def to_dict(self) -> None:
+        super(NamespacedResource, self)._base_body()
         self._base_body()
 
 
