@@ -178,7 +178,7 @@ class SecurityContextConstraints(Resource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.allow_host_dir_volume_plugin,
                 self.allow_host_ipc,
